@@ -12,7 +12,7 @@ NT_TYPE_PERIODIC = 'Periodic'
 NT_TYPE_REDUCIBLE = 'Reducible'  # Strictly this  means "reducible and not periodic".
 NT_TYPE_PSEUDO_ANOSOV = 'Pseudo-Anosov'
 
-class Encoding(object):
+class Encoding:
     ''' This represents a map between two Triagulations.
     
     If it maps to and from the same triangulation then it represents
@@ -107,8 +107,6 @@ class Encoding(object):
             return self.identify() == other.identify()
         else:
             return NotImplemented
-    def __ne__(self, other):
-        return not self == other
     def __hash__(self):
         return hash(self.identify())
     def is_homologous_to(self, other):
